==> tencentcloud-sdk-python-intl-en-3.0.607.tar.gz: tencentcloud-sdk-python-intl-en-3.0.607/tencentcloud/intlpartnersmgt/v20220928/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM signature/authentication error.
AUTHFAILURE = 'AuthFailure'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# FailedOperation.MailIsRegistered
FAILEDOPERATION_MAILISREGISTERED = 'FailedOperation.MailIsRegistered'

# Internal error.
INTERNALERROR = 'InternalError'

# InvalidParameter.AccountTypeContentIncorrect
INVALIDPARAMETER_ACCOUNTTYPECONTENTINCORRECT = 'InvalidParameter.AccountTypeContentIncorrect'

# InvalidParameter.AreaContentIncorrect
INVALIDPARAMETER_AREACONTENTINCORRECT = 'InvalidParameter.AreaContentIncorrect'

# InvalidParameter.AreaFormatIncorrect
INVALIDPARAMETER_AREAFORMATINCORRECT = 'InvalidParameter.AreaFormatIncorrect'

# InvalidParameter.ConfirmPasswordContentIncorrect
INVALIDPARAMETER_CONFIRMPASSWORDCONTENTINCORRECT = 'InvalidParameter.ConfirmPasswordContentIncorrect'

# InvalidParameter.CountryCodeContentIncorrect
INVALIDPARAMETER_COUNTRYCODECONTENTINCORRECT = 'InvalidParameter.CountryCodeContentIncorrect'

# InvalidParameter.CountryCodeFormatIncorrect
INVALIDPARAMETER_COUNTRYCODEFORMATINCORRECT = 'InvalidParameter.CountryCodeFormatIncorrect'

# InvalidParameter.MailFormatIncorrect
INVALIDPARAMETER_MAILFORMATINCORRECT = 'InvalidParameter.MailFormatIncorrect'

# InvalidParameter.PasswordContentIncorrect
INVALIDPARAMETER_PASSWORDCONTENTINCORRECT = 'InvalidParameter.PasswordContentIncorrect'

# InvalidParameter.PasswordFormatIncorrect
INVALIDPARAMETER_PASSWORDFORMATINCORRECT = 'InvalidParameter.PasswordFormatIncorrect'

# InvalidParameter.PhoneNumFormatIncorrect
INVALIDPARAMETER_PHONENUMFORMATINCORRECT = 'InvalidParameter.PhoneNumFormatIncorrect'

# Invalid parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# InvalidParameterValue.AccountTypeEmpty
INVALIDPARAMETERVALUE_ACCOUNTTYPEEMPTY = 'InvalidParameterValue.AccountTypeEmpty'

# InvalidParameterValue.AreaEmpty
INVALIDPARAMETERVALUE_AREAEMPTY = 'InvalidParameterValue.AreaEmpty'

# InvalidParameterValue.CountryCodeEmpty
INVALIDPARAMETERVALUE_COUNTRYCODEEMPTY = 'InvalidParameterValue.CountryCodeEmpty'

# InvalidParameterValue.MailEmpty
INVALIDPARAMETERVALUE_MAILEMPTY = 'InvalidParameterValue.MailEmpty'

# InvalidParameterValue.PasswordEmpty
INVALIDPARAMETERVALUE_PASSWORDEMPTY = 'InvalidParameterValue.PasswordEmpty'

# InvalidParameterValue.PhoneNumEmpty
INVALIDPARAMETERVALUE_PHONENUMEMPTY = 'InvalidParameterValue.PhoneNumEmpty'

# Operation denied.
OPERATIONDENIED = 'OperationDenied'

# Too many requests.
REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'

# Unauthorized operation.
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

==> tencentcloud-sdk-python-intl-en-3.0.672.tar.gz: tencentcloud-sdk-python-intl-en-3.0.672/tencentcloud/intlpartnersmgt/v20220928/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM signature/authentication error.
AUTHFAILURE = 'AuthFailure'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# FailedOperation.MailIsRegistered
FAILEDOPERATION_MAILISREGISTERED = 'FailedOperation.MailIsRegistered'

# Internal error.
INTERNALERROR = 'InternalError'

# InvalidParameter.AccountTypeContentIncorrect
INVALIDPARAMETER_ACCOUNTTYPECONTENTINCORRECT = 'InvalidParameter.AccountTypeContentIncorrect'

# InvalidParameter.AreaContentIncorrect
INVALIDPARAMETER_AREACONTENTINCORRECT = 'InvalidParameter.AreaContentIncorrect'

# InvalidParameter.AreaFormatIncorrect
INVALIDPARAMETER_AREAFORMATINCORRECT = 'InvalidParameter.AreaFormatIncorrect'

# InvalidParameter.ConfirmPasswordContentIncorrect
INVALIDPARAMETER_CONFIRMPASSWORDCONTENTINCORRECT = 'InvalidParameter.ConfirmPasswordContentIncorrect'

# InvalidParameter.CountryCodeContentIncorrect
INVALIDPARAMETER_COUNTRYCODECONTENTINCORRECT = 'InvalidParameter.CountryCodeContentIncorrect'

# InvalidParameter.CountryCodeFormatIncorrect
INVALIDPARAMETER_COUNTRYCODEFORMATINCORRECT = 'InvalidParameter.CountryCodeFormatIncorrect'

# InvalidParameter.MailFormatIncorrect
INVALIDPARAMETER_MAILFORMATINCORRECT = 'InvalidParameter.MailFormatIncorrect'

# InvalidParameter.PasswordContentIncorrect
INVALIDPARAMETER_PASSWORDCONTENTINCORRECT = 'InvalidParameter.PasswordContentIncorrect'

# InvalidParameter.PasswordFormatIncorrect
INVALIDPARAMETER_PASSWORDFORMATINCORRECT = 'InvalidParameter.PasswordFormatIncorrect'

# InvalidParameter.PhoneNumFormatIncorrect
INVALIDPARAMETER_PHONENUMFORMATINCORRECT = 'InvalidParameter.PhoneNumFormatIncorrect'

# Invalid parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# InvalidParameterValue.AccountTypeEmpty
INVALIDPARAMETERVALUE_ACCOUNTTYPEEMPTY = 'InvalidParameterValue.AccountTypeEmpty'

# InvalidParameterValue.AreaEmpty
INVALIDPARAMETERVALUE_AREAEMPTY = 'InvalidParameterValue.AreaEmpty'

# InvalidParameterValue.CountryCodeEmpty
INVALIDPARAMETERVALUE_COUNTRYCODEEMPTY = 'InvalidParameterValue.CountryCodeEmpty'

# InvalidParameterValue.MailEmpty
INVALIDPARAMETERVALUE_MAILEMPTY = 'InvalidParameterValue.MailEmpty'

# InvalidParameterValue.PasswordEmpty
INVALIDPARAMETERVALUE_PASSWORDEMPTY = 'InvalidParameterValue.PasswordEmpty'

# InvalidParameterValue.PhoneNumEmpty
INVALIDPARAMETERVALUE_PHONENUMEMPTY = 'InvalidParameterValue.PhoneNumEmpty'

# Operation denied.
OPERATIONDENIED = 'OperationDenied'

# System busy. Please try again later.
OPERATIONDENIED_SERVICEBUSY = 'OperationDenied.ServiceBusy'

# Too many requests.
REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'

# Unauthorized operation.
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# The current user doesn’t have permission for the operation.
UNAUTHORIZEDOPERATION_UINNOAUTH = 'UnauthorizedOperation.UinNoAuth'
